@@ -135,7 +135,7 @@ class Store(StorageInterface):
         for column in columns:
             if column.startswith('_'):
                 continue
-            if not full_access and column not in open_fields:
+            if open_fields and not full_access and column not in open_fields:
                 continue
             if hasattr(tiddler, column):
                 setattr(tiddler, column, unicode(getattr(stiddler, column)))
@@ -200,7 +200,7 @@ class Store(StorageInterface):
             have_query = True
 
         for field in fields:
-            if not full_access and field not in open_fields:
+            if open_fields and not full_access and field not in open_fields:
                 continue
             terms = fields[field]
             # TODO: For now we only accept the first term provided
@@ -218,6 +218,9 @@ class Store(StorageInterface):
                         'mappingsql.tasters', False)
             if tasters and not full_access:
                 query = query.filter(sTiddler.taster=='Y')
+            access_count = query.count()
+            logging.debug('access_count is: %s', access_count)
+            self.environ['tiddlyweb.mappingsql.access_count'] = access_count
             logging.debug('query is: %s', query)
             stiddlers = query.slice(slice_index, slice_index + limit).all()
         else:
